Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(233)

Unified Diff: tools/telemetry/telemetry/web_perf/metrics/webrtc_rendering_stats.py

Issue 1533523004: Run codespell on src/tools/telemetry. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: tools/telemetry/telemetry/web_perf/metrics/webrtc_rendering_stats.py
diff --git a/tools/telemetry/telemetry/web_perf/metrics/webrtc_rendering_stats.py b/tools/telemetry/telemetry/web_perf/metrics/webrtc_rendering_stats.py
index 55c72d0f46caa39d88a5433ad9508c820100731d..43276b6f5db293612b3eed785f7dcc3c4e95eadf 100644
--- a/tools/telemetry/telemetry/web_perf/metrics/webrtc_rendering_stats.py
+++ b/tools/telemetry/telemetry/web_perf/metrics/webrtc_rendering_stats.py
@@ -98,16 +98,16 @@ class WebMediaPlayerMsRenderingStats(object):
In this paragraph I will be using regex notation. What is intended by the
word cadence is a sort of extended instantaneous 'Cadence' (thus not
necessarily periodic). Just as an example, a normal 'Cadence' could be
- something like [2 3] which means possibly an observed frame persistance
+ something like [2 3] which means possibly an observed frame persistence
progression of [{2 3}+] for an ideal 20FPS video source. So what we are
calculating here is the list of frame persistance, kind of a
'Proto-Cadence', but cadence is shorter so we abuse the word.
Args:
relevant_events: list of Telemetry events.
Returns:
a list of frame persistance values.
"""
cadence = []
frame_persistence = 0
@@ -136,7 +136,7 @@ class WebMediaPlayerMsRenderingStats(object):
and p=Card(k in C).
Args:
cadence: list of frame persistance values.
Returns:
a dictionary containing the distribution
@@ -98,16 +98,16 @@ class WebMediaPlayerMsRenderingStats(object):
progression of [{2 3}+] for an ideal 20FPS video source. So what we are
- calculating here is the list of frame persistance, kind of a
+ calculating here is the list of frame persistence, kind of a
'Proto-Cadence', but cadence is shorter so we abuse the word.
Args:
@@ -98,16 +98,16 @@ class WebMediaPlayerMsRenderingStats(object):
relevant_events: list of Telemetry events.
Returns:
- a list of frame persistance values.
+ a list of frame persistence values.
"""
cadence = []
@@ -136,7 +136,7 @@ class WebMediaPlayerMsRenderingStats(object):
and p=Card(k in C).
Args:
- cadence: list of frame persistance values.
+ cadence: list of frame persistence values.
Returns:
a dictionary containing the distribution

Powered by Google App Engine
This is Rietveld 408576698